// Copyright (c) 2023 Dominic Masters
// 
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT

#include "game/Game.hpp"
#include "game/GameInit.hpp"
#include "scene/Scene.hpp"

using namespace Dawn;

Game::Game() {

}

void Game::init() {
  renderHost.init(shared_from_this());
  inputManager.init(shared_from_this());

  auto initialScene = GameInit::getInitialScene();
  nextFrameScene = std::make_shared<Scene>(shared_from_this(), initialScene);
}

void Game::update() {
  renderHost.update(shared_from_this());

  if(nextFrameScene) {
    nextFrameScene->stage();
    currentScene = nextFrameScene;
    nextFrameScene = nullptr;
  }
}

bool_t Game::isCloseRequested() {
  return (
    renderHost.isCloseRequested()
  );
}

std::shared_ptr<Scene> Game::getCurrentScene() {
  return currentScene;
}

Game::~Game() {
  std::cout << "Game successfully destructed" << std::endl;
}